# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.44.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model
from accelbyte_py_sdk.core import StrEnum


class BalanceOriginEnum(StrEnum):
    EPIC = "Epic"
    GOOGLEPLAY = "GooglePlay"
    IOS = "IOS"
    NINTENDO = "Nintendo"
    OCULUS = "Oculus"
    OTHER = "Other"
    PLAYSTATION = "Playstation"
    STEAM = "Steam"
    SYSTEM = "System"
    TWITCH = "Twitch"
    XBOX = "Xbox"


class BalanceSourceEnum(StrEnum):
    DLC_REVOCATION = "DLC_REVOCATION"
    EXPIRATION = "EXPIRATION"
    IAP_REVOCATION = "IAP_REVOCATION"
    ORDER_REVOCATION = "ORDER_REVOCATION"
    OTHER = "OTHER"
    PAYMENT = "PAYMENT"
    TRADE = "TRADE"


class DebitByCurrencyCodeRequest(Model):
    """A DTO for wallet's debit (DebitByCurrencyCodeRequest)

    Properties:
        amount: (amount) REQUIRED int

        allow_overdraft: (allowOverdraft) OPTIONAL bool

        balance_origin: (balanceOrigin) OPTIONAL Union[str, BalanceOriginEnum]

        balance_source: (balanceSource) OPTIONAL Union[str, BalanceSourceEnum]

        metadata: (metadata) OPTIONAL Dict[str, Any]

        reason: (reason) OPTIONAL str
    """

    # region fields

    amount: int  # REQUIRED
    allow_overdraft: bool  # OPTIONAL
    balance_origin: Union[str, BalanceOriginEnum]  # OPTIONAL
    balance_source: Union[str, BalanceSourceEnum]  # OPTIONAL
    metadata: Dict[str, Any]  # OPTIONAL
    reason: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_amount(self, value: int) -> DebitByCurrencyCodeRequest:
        self.amount = value
        return self

    def with_allow_overdraft(self, value: bool) -> DebitByCurrencyCodeRequest:
        self.allow_overdraft = value
        return self

    def with_balance_origin(
        self, value: Union[str, BalanceOriginEnum]
    ) -> DebitByCurrencyCodeRequest:
        self.balance_origin = value
        return self

    def with_balance_source(
        self, value: Union[str, BalanceSourceEnum]
    ) -> DebitByCurrencyCodeRequest:
        self.balance_source = value
        return self

    def with_metadata(self, value: Dict[str, Any]) -> DebitByCurrencyCodeRequest:
        self.metadata = value
        return self

    def with_reason(self, value: str) -> DebitByCurrencyCodeRequest:
        self.reason = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "amount"):
            result["amount"] = int(self.amount)
        elif include_empty:
            result["amount"] = 0
        if hasattr(self, "allow_overdraft"):
            result["allowOverdraft"] = bool(self.allow_overdraft)
        elif include_empty:
            result["allowOverdraft"] = False
        if hasattr(self, "balance_origin"):
            result["balanceOrigin"] = str(self.balance_origin)
        elif include_empty:
            result["balanceOrigin"] = Union[str, BalanceOriginEnum]()
        if hasattr(self, "balance_source"):
            result["balanceSource"] = str(self.balance_source)
        elif include_empty:
            result["balanceSource"] = Union[str, BalanceSourceEnum]()
        if hasattr(self, "metadata"):
            result["metadata"] = {str(k0): v0 for k0, v0 in self.metadata.items()}
        elif include_empty:
            result["metadata"] = {}
        if hasattr(self, "reason"):
            result["reason"] = str(self.reason)
        elif include_empty:
            result["reason"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        amount: int,
        allow_overdraft: Optional[bool] = None,
        balance_origin: Optional[Union[str, BalanceOriginEnum]] = None,
        balance_source: Optional[Union[str, BalanceSourceEnum]] = None,
        metadata: Optional[Dict[str, Any]] = None,
        reason: Optional[str] = None,
        **kwargs,
    ) -> DebitByCurrencyCodeRequest:
        instance = cls()
        instance.amount = amount
        if allow_overdraft is not None:
            instance.allow_overdraft = allow_overdraft
        if balance_origin is not None:
            instance.balance_origin = balance_origin
        if balance_source is not None:
            instance.balance_source = balance_source
        if metadata is not None:
            instance.metadata = metadata
        if reason is not None:
            instance.reason = reason
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> DebitByCurrencyCodeRequest:
        instance = cls()
        if not dict_:
            return instance
        if "amount" in dict_ and dict_["amount"] is not None:
            instance.amount = int(dict_["amount"])
        elif include_empty:
            instance.amount = 0
        if "allowOverdraft" in dict_ and dict_["allowOverdraft"] is not None:
            instance.allow_overdraft = bool(dict_["allowOverdraft"])
        elif include_empty:
            instance.allow_overdraft = False
        if "balanceOrigin" in dict_ and dict_["balanceOrigin"] is not None:
            instance.balance_origin = str(dict_["balanceOrigin"])
        elif include_empty:
            instance.balance_origin = Union[str, BalanceOriginEnum]()
        if "balanceSource" in dict_ and dict_["balanceSource"] is not None:
            instance.balance_source = str(dict_["balanceSource"])
        elif include_empty:
            instance.balance_source = Union[str, BalanceSourceEnum]()
        if "metadata" in dict_ and dict_["metadata"] is not None:
            instance.metadata = {str(k0): v0 for k0, v0 in dict_["metadata"].items()}
        elif include_empty:
            instance.metadata = {}
        if "reason" in dict_ and dict_["reason"] is not None:
            instance.reason = str(dict_["reason"])
        elif include_empty:
            instance.reason = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, DebitByCurrencyCodeRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[DebitByCurrencyCodeRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        DebitByCurrencyCodeRequest,
        List[DebitByCurrencyCodeRequest],
        Dict[Any, DebitByCurrencyCodeRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "amount": "amount",
            "allowOverdraft": "allow_overdraft",
            "balanceOrigin": "balance_origin",
            "balanceSource": "balance_source",
            "metadata": "metadata",
            "reason": "reason",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "amount": True,
            "allowOverdraft": False,
            "balanceOrigin": False,
            "balanceSource": False,
            "metadata": False,
            "reason": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "balanceOrigin": [
                "Epic",
                "GooglePlay",
                "IOS",
                "Nintendo",
                "Oculus",
                "Other",
                "Playstation",
                "Steam",
                "System",
                "Twitch",
                "Xbox",
            ],
            "balanceSource": [
                "DLC_REVOCATION",
                "EXPIRATION",
                "IAP_REVOCATION",
                "ORDER_REVOCATION",
                "OTHER",
                "PAYMENT",
                "TRADE",
            ],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.44.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ClientTransaction(Model):
    """Client transaction (ClientTransaction)

    Properties:
        amount_consumed: (amountConsumed) OPTIONAL int

        client_transaction_id: (clientTransactionId) OPTIONAL str
    """

    # region fields

    amount_consumed: int  # OPTIONAL
    client_transaction_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_amount_consumed(self, value: int) -> ClientTransaction:
        self.amount_consumed = value
        return self

    def with_client_transaction_id(self, value: str) -> ClientTransaction:
        self.client_transaction_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "amount_consumed"):
            result["amountConsumed"] = int(self.amount_consumed)
        elif include_empty:
            result["amountConsumed"] = 0
        if hasattr(self, "client_transaction_id"):
            result["clientTransactionId"] = str(self.client_transaction_id)
        elif include_empty:
            result["clientTransactionId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        amount_consumed: Optional[int] = None,
        client_transaction_id: Optional[str] = None,
        **kwargs,
    ) -> ClientTransaction:
        instance = cls()
        if amount_consumed is not None:
            instance.amount_consumed = amount_consumed
        if client_transaction_id is not None:
            instance.client_transaction_id = client_transaction_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ClientTransaction:
        instance = cls()
        if not dict_:
            return instance
        if "amountConsumed" in dict_ and dict_["amountConsumed"] is not None:
            instance.amount_consumed = int(dict_["amountConsumed"])
        elif include_empty:
            instance.amount_consumed = 0
        if "clientTransactionId" in dict_ and dict_["clientTransactionId"] is not None:
            instance.client_transaction_id = str(dict_["clientTransactionId"])
        elif include_empty:
            instance.client_transaction_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ClientTransaction]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ClientTransaction]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ClientTransaction, List[ClientTransaction], Dict[Any, ClientTransaction]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "amountConsumed": "amount_consumed",
            "clientTransactionId": "client_transaction_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "amountConsumed": False,
            "clientTransactionId": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import DLCConfigRewardShortInfo
from ..models import DLCItemConfigInfo
from ..models import DLCItemConfigUpdate
from ..models import EpicGamesDLCSyncRequest
from ..models import ErrorEntity
from ..models import PlatformDLCConfigInfo
from ..models import PlatformDLCConfigUpdate
from ..models import PlayStationDLCSyncMultiServiceLabelsRequest
from ..models import PlayStationDLCSyncRequest
from ..models import SteamDLCSyncRequest
from ..models import UserDLC
from ..models import UserDLCRecord
from ..models import ValidationErrorEntity
from ..models import XblDLCSyncRequest

from ..operations.dlc import DeleteDLCItemConfig
from ..operations.dlc import DeletePlatformDLCConfig
from ..operations.dlc import GeDLCDurableRewardShortMap
from ..operations.dlc import GeDLCDurableRewardShortMapDlcTypeEnum
from ..operations.dlc import GetDLCItemConfig
from ..operations.dlc import GetPlatformDLCConfig
from ..operations.dlc import GetUserDLC
from ..operations.dlc import GetUserDLCTypeEnum
from ..operations.dlc import GetUserDLCByPlatform
from ..operations.dlc import GetUserDLCByPlatformTypeEnum
from ..operations.dlc import PublicSyncPsnDlcInventory
from ..operations.dlc import PublicSyncPsnDlcInventoryWithMultipleServiceLabels
from ..operations.dlc import SyncEpicGameDLC
from ..operations.dlc import SyncOculusDLC
from ..operations.dlc import SyncSteamDLC
from ..operations.dlc import SyncXboxDLC
from ..operations.dlc import UpdateDLCItemConfig
from ..operations.dlc import UpdatePlatformDLCConfig
from ..models import DLCConfigRewardShortInfoDlcTypeEnum
from ..models import UserDLCPlatformEnum
from ..models import (
    UserDLCRecordEntitlementOriginSyncStatusEnum,
    UserDLCRecordPlatformEnum,
    UserDLCRecordStatusEnum,
)


@same_doc_as(DeleteDLCItemConfig)
def delete_dlc_item_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """delete a DLC item config (deleteDLCItemConfig)

    delete a DLC item config.
    Other detail info:

      * Required permission : resource= "ADMIN:NAMESPACE:{namespace}:DLC:CONFIG" , action=8 (DELETE)

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [DELETE]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/item

        method: DELETE

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteDLCItemConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteDLCItemConfig)
async def delete_dlc_item_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """delete a DLC item config (deleteDLCItemConfig)

    delete a DLC item config.
    Other detail info:

      * Required permission : resource= "ADMIN:NAMESPACE:{namespace}:DLC:CONFIG" , action=8 (DELETE)

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [DELETE]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/item

        method: DELETE

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteDLCItemConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeletePlatformDLCConfig)
def delete_platform_dlc_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """delete a Platform DLC config (deletePlatformDLCConfig)

    delete a Platform DLC config.
    Other detail info:

      * Required permission : resource= "ADMIN:NAMESPACE:{namespace}:DLC:CONFIG" , action=8 (DELETE)

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [DELETE]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/platformMap

        method: DELETE

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeletePlatformDLCConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeletePlatformDLCConfig)
async def delete_platform_dlc_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """delete a Platform DLC config (deletePlatformDLCConfig)

    delete a Platform DLC config.
    Other detail info:

      * Required permission : resource= "ADMIN:NAMESPACE:{namespace}:DLC:CONFIG" , action=8 (DELETE)

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [DELETE]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/platformMap

        method: DELETE

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Delete successfully)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeletePlatformDLCConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GeDLCDurableRewardShortMap)
def ge_dlc_durable_reward_short_map(
    dlc_type: Union[str, GeDLCDurableRewardShortMapDlcTypeEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get dlc durable reward simple map (geDLCDurableRewardShortMap)

    Get dlc reward simple map, only return the sku of durable item reward
    Other detail info:

      * Required permission : Authorized user

    Properties:
        url: /platform/public/namespaces/{namespace}/dlc/rewards/durable/map

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        dlc_type: (dlcType) REQUIRED Union[str, DlcTypeEnum] in query

    Responses:
        200: OK - DLCConfigRewardShortInfo (successful operation)

        404: Not Found - ErrorEntity (39442: DLC item config cannot be found in namespace [{namespace}] | 39441: Platform dlc config cannot be found in namespace [{namespace}] | 30341: Item [{itemId}] does not exist in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GeDLCDurableRewardShortMap.create(
        dlc_type=dlc_type,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GeDLCDurableRewardShortMap)
async def ge_dlc_durable_reward_short_map_async(
    dlc_type: Union[str, GeDLCDurableRewardShortMapDlcTypeEnum],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get dlc durable reward simple map (geDLCDurableRewardShortMap)

    Get dlc reward simple map, only return the sku of durable item reward
    Other detail info:

      * Required permission : Authorized user

    Properties:
        url: /platform/public/namespaces/{namespace}/dlc/rewards/durable/map

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        dlc_type: (dlcType) REQUIRED Union[str, DlcTypeEnum] in query

    Responses:
        200: OK - DLCConfigRewardShortInfo (successful operation)

        404: Not Found - ErrorEntity (39442: DLC item config cannot be found in namespace [{namespace}] | 39441: Platform dlc config cannot be found in namespace [{namespace}] | 30341: Item [{itemId}] does not exist in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GeDLCDurableRewardShortMap.create(
        dlc_type=dlc_type,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetDLCItemConfig)
def get_dlc_item_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get DLC item config (getDLCItemConfig)

    Get DLC item config.
    Other detail info:

      * Required permission : resource= "ADMIN:NAMESPACE:{namespace}:DLC:CONFIG" , action=2 (READ)

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [READ]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/item

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DLCItemConfigInfo (successful operation)

        404: Not Found - ErrorEntity (39442: DLC item config cannot be found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetDLCItemConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetDLCItemConfig)
async def get_dlc_item_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get DLC item config (getDLCItemConfig)

    Get DLC item config.
    Other detail info:

      * Required permission : resource= "ADMIN:NAMESPACE:{namespace}:DLC:CONFIG" , action=2 (READ)

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [READ]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/item

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DLCItemConfigInfo (successful operation)

        404: Not Found - ErrorEntity (39442: DLC item config cannot be found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetDLCItemConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetPlatformDLCConfig)
def get_platform_dlc_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Platform DLC config (getPlatformDLCConfig)

    Get Platform DLC config.
    Other detail info:

      * Required permission : resource= "ADMIN:NAMESPACE:{namespace}:DLC:CONFIG" , action=2 (READ)

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [READ]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/platformMap

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - PlatformDLCConfigInfo (successful operation)

        404: Not Found - ErrorEntity (39341: Platform DLC config cannot be found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetPlatformDLCConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetPlatformDLCConfig)
async def get_platform_dlc_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Platform DLC config (getPlatformDLCConfig)

    Get Platform DLC config.
    Other detail info:

      * Required permission : resource= "ADMIN:NAMESPACE:{namespace}:DLC:CONFIG" , action=2 (READ)

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [READ]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/platformMap

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: []

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - PlatformDLCConfigInfo (successful operation)

        404: Not Found - ErrorEntity (39341: Platform DLC config cannot be found in namespace [{namespace}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetPlatformDLCConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetUserDLC)
def get_user_dlc(
    user_id: str,
    type_: Optional[Union[str, GetUserDLCTypeEnum]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user dlc records (getUserDLC)

    Get user dlc records.
    Other detail info:

      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:USER:{userId}:IAP", action=2 (READ)
      *  Returns : user dlc

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:USER:{userId}:IAP [READ]

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/dlc/records

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        type_: (type) OPTIONAL Union[str, TypeEnum] in query

    Responses:
        200: OK - List[UserDLCRecord] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserDLC.create(
        user_id=user_id,
        type_=type_,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetUserDLC)
async def get_user_dlc_async(
    user_id: str,
    type_: Optional[Union[str, GetUserDLCTypeEnum]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user dlc records (getUserDLC)

    Get user dlc records.
    Other detail info:

      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:USER:{userId}:IAP", action=2 (READ)
      *  Returns : user dlc

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:USER:{userId}:IAP [READ]

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/dlc/records

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        type_: (type) OPTIONAL Union[str, TypeEnum] in query

    Responses:
        200: OK - List[UserDLCRecord] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserDLC.create(
        user_id=user_id,
        type_=type_,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetUserDLCByPlatform)
def get_user_dlc_by_platform(
    type_: Union[str, GetUserDLCByPlatformTypeEnum],
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user dlc by platform (getUserDLCByPlatform)

    Get user dlc by platform.
    Other detail info:

      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:USER:{userId}:IAP", action=2 (READ)
      *  Returns : user dlc

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:USER:{userId}:IAP [READ]

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/dlc

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        type_: (type) REQUIRED Union[str, TypeEnum] in query

    Responses:
        200: OK - UserDLC (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserDLCByPlatform.create(
        type_=type_,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetUserDLCByPlatform)
async def get_user_dlc_by_platform_async(
    type_: Union[str, GetUserDLCByPlatformTypeEnum],
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user dlc by platform (getUserDLCByPlatform)

    Get user dlc by platform.
    Other detail info:

      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:USER:{userId}:IAP", action=2 (READ)
      *  Returns : user dlc

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:USER:{userId}:IAP [READ]

    Properties:
        url: /platform/admin/namespaces/{namespace}/users/{userId}/dlc

        method: GET

        tags: ["DLC"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        type_: (type) REQUIRED Union[str, TypeEnum] in query

    Responses:
        200: OK - UserDLC (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserDLCByPlatform.create(
        type_=type_,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicSyncPsnDlcInventory)
def public_sync_psn_dlc_inventory(
    user_id: str,
    body: Optional[PlayStationDLCSyncRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Synchronize with dlc entitlements in PSN Store. (publicSyncPsnDlcInventory)

    Synchronize with dlc entitlements in PSN Store.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns : result of synchronization

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/psn/sync

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL PlayStationDLCSyncRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39125: Invalid platform [{platformId}] user token | 39126: User id [{}] in namespace [{}] doesn't link platform [{}] | 39127: Invalid service label [{serviceLabel}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicSyncPsnDlcInventory.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicSyncPsnDlcInventory)
async def public_sync_psn_dlc_inventory_async(
    user_id: str,
    body: Optional[PlayStationDLCSyncRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Synchronize with dlc entitlements in PSN Store. (publicSyncPsnDlcInventory)

    Synchronize with dlc entitlements in PSN Store.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns : result of synchronization

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/psn/sync

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL PlayStationDLCSyncRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39125: Invalid platform [{platformId}] user token | 39126: User id [{}] in namespace [{}] doesn't link platform [{}] | 39127: Invalid service label [{serviceLabel}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicSyncPsnDlcInventory.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicSyncPsnDlcInventoryWithMultipleServiceLabels)
def public_sync_psn_dlc_inventory_with_multiple_service_labels(
    user_id: str,
    body: Optional[PlayStationDLCSyncMultiServiceLabelsRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Synchronize with dlc entitlements in PSN Store with multiple service labels. (publicSyncPsnDlcInventoryWithMultipleServiceLabels)

    Synchronize with dlc entitlements in PSN Store with multiple service labels.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns : result of synchronization

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/psn/sync/multiServiceLabels

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL PlayStationDLCSyncMultiServiceLabelsRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39125: Invalid platform [{platformId}] user token | 39126: User id [{}] in namespace [{}] doesn't link platform [{}] | 39127: Invalid service label [{serviceLabel}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicSyncPsnDlcInventoryWithMultipleServiceLabels.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicSyncPsnDlcInventoryWithMultipleServiceLabels)
async def public_sync_psn_dlc_inventory_with_multiple_service_labels_async(
    user_id: str,
    body: Optional[PlayStationDLCSyncMultiServiceLabelsRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Synchronize with dlc entitlements in PSN Store with multiple service labels. (publicSyncPsnDlcInventoryWithMultipleServiceLabels)

    Synchronize with dlc entitlements in PSN Store with multiple service labels.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns : result of synchronization

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/psn/sync/multiServiceLabels

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL PlayStationDLCSyncMultiServiceLabelsRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39125: Invalid platform [{platformId}] user token | 39126: User id [{}] in namespace [{}] doesn't link platform [{}] | 39127: Invalid service label [{serviceLabel}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicSyncPsnDlcInventoryWithMultipleServiceLabels.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SyncEpicGameDLC)
def sync_epic_game_dlc(
    user_id: str,
    body: Optional[EpicGamesDLCSyncRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync epic games dlc items (syncEpicGameDLC)

    Sync epic games dlc items.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/epicgames/sync

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL EpicGamesDLCSyncRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39125: Invalid platform [{platformId}] user token | 39126: User id [{}] in namespace [{}] doesn't link platform [{}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncEpicGameDLC.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SyncEpicGameDLC)
async def sync_epic_game_dlc_async(
    user_id: str,
    body: Optional[EpicGamesDLCSyncRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync epic games dlc items (syncEpicGameDLC)

    Sync epic games dlc items.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/epicgames/sync

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL EpicGamesDLCSyncRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39125: Invalid platform [{platformId}] user token | 39126: User id [{}] in namespace [{}] doesn't link platform [{}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncEpicGameDLC.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SyncOculusDLC)
def sync_oculus_dlc(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync oculus dlc. (syncOculusDLC)

    Sync oculus dlc.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/oculus/sync

        method: PUT

        tags: ["DLC"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39124: IAP request platform [{platformId}] user id is not linked with current user)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncOculusDLC.create(
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SyncOculusDLC)
async def sync_oculus_dlc_async(
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync oculus dlc. (syncOculusDLC)

    Sync oculus dlc.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/oculus/sync

        method: PUT

        tags: ["DLC"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39124: IAP request platform [{platformId}] user id is not linked with current user)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncOculusDLC.create(
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SyncSteamDLC)
def sync_steam_dlc(
    user_id: str,
    body: Optional[SteamDLCSyncRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync steam dlc. (syncSteamDLC)

    Sync steam dlc.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/steam/sync

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL SteamDLCSyncRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39124: IAP request platform [{platformId}] user id is not linked with current user)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncSteamDLC.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SyncSteamDLC)
async def sync_steam_dlc_async(
    user_id: str,
    body: Optional[SteamDLCSyncRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync steam dlc. (syncSteamDLC)

    Sync steam dlc.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/steam/sync

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL SteamDLCSyncRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39124: IAP request platform [{platformId}] user id is not linked with current user)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncSteamDLC.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SyncXboxDLC)
def sync_xbox_dlc(
    user_id: str,
    body: Optional[XblDLCSyncRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync Xbox dlc items. (syncXboxDLC)

    Sync Xbox inventory's dlc items.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/xbl/sync

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL XblDLCSyncRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39125: Invalid platform [{platformId}] user token | 39126: User id [{}] in namespace [{}] doesn't link platform [{}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncXboxDLC.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SyncXboxDLC)
async def sync_xbox_dlc_async(
    user_id: str,
    body: Optional[XblDLCSyncRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync Xbox dlc items. (syncXboxDLC)

    Sync Xbox inventory's dlc items.

    Other detail info:

      * Required permission : resource=NAMESPACE:{namespace}:USER:{userId}:DLC, action=4 (UPDATE)
      *  Returns :

    Properties:
        url: /platform/public/namespaces/{namespace}/users/{userId}/dlc/xbl/sync

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL XblDLCSyncRequest in body

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (Successful operation)

        400: Bad Request - ErrorEntity (39125: Invalid platform [{platformId}] user token | 39126: User id [{}] in namespace [{}] doesn't link platform [{}])
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SyncXboxDLC.create(
        user_id=user_id,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateDLCItemConfig)
def update_dlc_item_config(
    body: Optional[DLCItemConfigUpdate] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update DLC item config (updateDLCItemConfig)

    Update DLC item config. Other detail info:
      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:DLC:CONFIG", action=4 (UPDATE)
      *  Returns : updated DLC item config

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [UPDATE]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/item

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        body: (body) OPTIONAL DLCItemConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DLCItemConfigInfo (successful operation)

        400: Bad Request - ErrorEntity (394721: Invalid platform DLC config namespace [{namespace}]: [{message}])

        409: Conflict - ErrorEntity (39471: Duplicated dlc reward id [{dlcRewardId}] in namespace [{namespace}] )

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateDLCItemConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateDLCItemConfig)
async def update_dlc_item_config_async(
    body: Optional[DLCItemConfigUpdate] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update DLC item config (updateDLCItemConfig)

    Update DLC item config. Other detail info:
      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:DLC:CONFIG", action=4 (UPDATE)
      *  Returns : updated DLC item config

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [UPDATE]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/item

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        body: (body) OPTIONAL DLCItemConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - DLCItemConfigInfo (successful operation)

        400: Bad Request - ErrorEntity (394721: Invalid platform DLC config namespace [{namespace}]: [{message}])

        409: Conflict - ErrorEntity (39471: Duplicated dlc reward id [{dlcRewardId}] in namespace [{namespace}] )

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateDLCItemConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdatePlatformDLCConfig)
def update_platform_dlc_config(
    body: Optional[PlatformDLCConfigUpdate] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Platform DLC config (updatePlatformDLCConfig)

    Update Platform DLC config. Other detail info:
      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:DLC:CONFIG", action=4 (UPDATE)
      *  Returns : updated Platform DLC config



    ## Restrictions for platform dlc map


    1. Cannot use "." as the key name
    -


        { "data.2": "value" }


    2. Cannot use "$" as the prefix in key names
    -


        { "$data": "value" }

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [UPDATE]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/platformMap

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        body: (body) OPTIONAL PlatformDLCConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - PlatformDLCConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdatePlatformDLCConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdatePlatformDLCConfig)
async def update_platform_dlc_config_async(
    body: Optional[PlatformDLCConfigUpdate] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update Platform DLC config (updatePlatformDLCConfig)

    Update Platform DLC config. Other detail info:
      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:DLC:CONFIG", action=4 (UPDATE)
      *  Returns : updated Platform DLC config



    ## Restrictions for platform dlc map


    1. Cannot use "." as the key name
    -


        { "data.2": "value" }


    2. Cannot use "$" as the prefix in key names
    -


        { "$data": "value" }

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:DLC:CONFIG [UPDATE]

    Properties:
        url: /platform/admin/namespaces/{namespace}/dlc/config/platformMap

        method: PUT

        tags: ["DLC"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        body: (body) OPTIONAL PlatformDLCConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - PlatformDLCConfigInfo (successful operation)

        422: Unprocessable Entity - ValidationErrorEntity (20002: validation error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdatePlatformDLCConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.44.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class AdyenConfig(Model):
    """A DTO object for updating adyen config. (AdyenConfig)

    Properties:
        allowed_payment_methods: (allowedPaymentMethods) OPTIONAL List[str]

        api_key: (apiKey) OPTIONAL str

        authorise_as_capture: (authoriseAsCapture) OPTIONAL bool

        blocked_payment_methods: (blockedPaymentMethods) OPTIONAL List[str]

        client_key: (clientKey) OPTIONAL str

        drop_in_settings: (dropInSettings) OPTIONAL str

        live_endpoint_url_prefix: (liveEndpointUrlPrefix) OPTIONAL str

        merchant_account: (merchantAccount) OPTIONAL str

        notification_hmac_key: (notificationHmacKey) OPTIONAL str

        notification_password: (notificationPassword) OPTIONAL str

        notification_username: (notificationUsername) OPTIONAL str

        return_url: (returnUrl) OPTIONAL str

        settings: (settings) OPTIONAL str
    """

    # region fields

    allowed_payment_methods: List[str]  # OPTIONAL
    api_key: str  # OPTIONAL
    authorise_as_capture: bool  # OPTIONAL
    blocked_payment_methods: List[str]  # OPTIONAL
    client_key: str  # OPTIONAL
    drop_in_settings: str  # OPTIONAL
    live_endpoint_url_prefix: str  # OPTIONAL
    merchant_account: str  # OPTIONAL
    notification_hmac_key: str  # OPTIONAL
    notification_password: str  # OPTIONAL
    notification_username: str  # OPTIONAL
    return_url: str  # OPTIONAL
    settings: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_allowed_payment_methods(self, value: List[str]) -> AdyenConfig:
        self.allowed_payment_methods = value
        return self

    def with_api_key(self, value: str) -> AdyenConfig:
        self.api_key = value
        return self

    def with_authorise_as_capture(self, value: bool) -> AdyenConfig:
        self.authorise_as_capture = value
        return self

    def with_blocked_payment_methods(self, value: List[str]) -> AdyenConfig:
        self.blocked_payment_methods = value
        return self

    def with_client_key(self, value: str) -> AdyenConfig:
        self.client_key = value
        return self

    def with_drop_in_settings(self, value: str) -> AdyenConfig:
        self.drop_in_settings = value
        return self

    def with_live_endpoint_url_prefix(self, value: str) -> AdyenConfig:
        self.live_endpoint_url_prefix = value
        return self

    def with_merchant_account(self, value: str) -> AdyenConfig:
        self.merchant_account = value
        return self

    def with_notification_hmac_key(self, value: str) -> AdyenConfig:
        self.notification_hmac_key = value
        return self

    def with_notification_password(self, value: str) -> AdyenConfig:
        self.notification_password = value
        return self

    def with_notification_username(self, value: str) -> AdyenConfig:
        self.notification_username = value
        return self

    def with_return_url(self, value: str) -> AdyenConfig:
        self.return_url = value
        return self

    def with_settings(self, value: str) -> AdyenConfig:
        self.settings = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "allowed_payment_methods"):
            result["allowedPaymentMethods"] = [
                str(i0) for i0 in self.allowed_payment_methods
            ]
        elif include_empty:
            result["allowedPaymentMethods"] = []
        if hasattr(self, "api_key"):
            result["apiKey"] = str(self.api_key)
        elif include_empty:
            result["apiKey"] = ""
        if hasattr(self, "authorise_as_capture"):
            result["authoriseAsCapture"] = bool(self.authorise_as_capture)
        elif include_empty:
            result["authoriseAsCapture"] = False
        if hasattr(self, "blocked_payment_methods"):
            result["blockedPaymentMethods"] = [
                str(i0) for i0 in self.blocked_payment_methods
            ]
        elif include_empty:
            result["blockedPaymentMethods"] = []
        if hasattr(self, "client_key"):
            result["clientKey"] = str(self.client_key)
        elif include_empty:
            result["clientKey"] = ""
        if hasattr(self, "drop_in_settings"):
            result["dropInSettings"] = str(self.drop_in_settings)
        elif include_empty:
            result["dropInSettings"] = ""
        if hasattr(self, "live_endpoint_url_prefix"):
            result["liveEndpointUrlPrefix"] = str(self.live_endpoint_url_prefix)
        elif include_empty:
            result["liveEndpointUrlPrefix"] = ""
        if hasattr(self, "merchant_account"):
            result["merchantAccount"] = str(self.merchant_account)
        elif include_empty:
            result["merchantAccount"] = ""
        if hasattr(self, "notification_hmac_key"):
            result["notificationHmacKey"] = str(self.notification_hmac_key)
        elif include_empty:
            result["notificationHmacKey"] = ""
        if hasattr(self, "notification_password"):
            result["notificationPassword"] = str(self.notification_password)
        elif include_empty:
            result["notificationPassword"] = ""
        if hasattr(self, "notification_username"):
            result["notificationUsername"] = str(self.notification_username)
        elif include_empty:
            result["notificationUsername"] = ""
        if hasattr(self, "return_url"):
            result["returnUrl"] = str(self.return_url)
        elif include_empty:
            result["returnUrl"] = ""
        if hasattr(self, "settings"):
            result["settings"] = str(self.settings)
        elif include_empty:
            result["settings"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        allowed_payment_methods: Optional[List[str]] = None,
        api_key: Optional[str] = None,
        authorise_as_capture: Optional[bool] = None,
        blocked_payment_methods: Optional[List[str]] = None,
        client_key: Optional[str] = None,
        drop_in_settings: Optional[str] = None,
        live_endpoint_url_prefix: Optional[str] = None,
        merchant_account: Optional[str] = None,
        notification_hmac_key: Optional[str] = None,
        notification_password: Optional[str] = None,
        notification_username: Optional[str] = None,
        return_url: Optional[str] = None,
        settings: Optional[str] = None,
        **kwargs,
    ) -> AdyenConfig:
        instance = cls()
        if allowed_payment_methods is not None:
            instance.allowed_payment_methods = allowed_payment_methods
        if api_key is not None:
            instance.api_key = api_key
        if authorise_as_capture is not None:
            instance.authorise_as_capture = authorise_as_capture
        if blocked_payment_methods is not None:
            instance.blocked_payment_methods = blocked_payment_methods
        if client_key is not None:
            instance.client_key = client_key
        if drop_in_settings is not None:
            instance.drop_in_settings = drop_in_settings
        if live_endpoint_url_prefix is not None:
            instance.live_endpoint_url_prefix = live_endpoint_url_prefix
        if merchant_account is not None:
            instance.merchant_account = merchant_account
        if notification_hmac_key is not None:
            instance.notification_hmac_key = notification_hmac_key
        if notification_password is not None:
            instance.notification_password = notification_password
        if notification_username is not None:
            instance.notification_username = notification_username
        if return_url is not None:
            instance.return_url = return_url
        if settings is not None:
            instance.settings = settings
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> AdyenConfig:
        instance = cls()
        if not dict_:
            return instance
        if (
            "allowedPaymentMethods" in dict_
            and dict_["allowedPaymentMethods"] is not None
        ):
            instance.allowed_payment_methods = [
                str(i0) for i0 in dict_["allowedPaymentMethods"]
            ]
        elif include_empty:
            instance.allowed_payment_methods = []
        if "apiKey" in dict_ and dict_["apiKey"] is not None:
            instance.api_key = str(dict_["apiKey"])
        elif include_empty:
            instance.api_key = ""
        if "authoriseAsCapture" in dict_ and dict_["authoriseAsCapture"] is not None:
            instance.authorise_as_capture = bool(dict_["authoriseAsCapture"])
        elif include_empty:
            instance.authorise_as_capture = False
        if (
            "blockedPaymentMethods" in dict_
            and dict_["blockedPaymentMethods"] is not None
        ):
            instance.blocked_payment_methods = [
                str(i0) for i0 in dict_["blockedPaymentMethods"]
            ]
        elif include_empty:
            instance.blocked_payment_methods = []
        if "clientKey" in dict_ and dict_["clientKey"] is not None:
            instance.client_key = str(dict_["clientKey"])
        elif include_empty:
            instance.client_key = ""
        if "dropInSettings" in dict_ and dict_["dropInSettings"] is not None:
            instance.drop_in_settings = str(dict_["dropInSettings"])
        elif include_empty:
            instance.drop_in_settings = ""
        if (
            "liveEndpointUrlPrefix" in dict_
            and dict_["liveEndpointUrlPrefix"] is not None
        ):
            instance.live_endpoint_url_prefix = str(dict_["liveEndpointUrlPrefix"])
        elif include_empty:
            instance.live_endpoint_url_prefix = ""
        if "merchantAccount" in dict_ and dict_["merchantAccount"] is not None:
            instance.merchant_account = str(dict_["merchantAccount"])
        elif include_empty:
            instance.merchant_account = ""
        if "notificationHmacKey" in dict_ and dict_["notificationHmacKey"] is not None:
            instance.notification_hmac_key = str(dict_["notificationHmacKey"])
        elif include_empty:
            instance.notification_hmac_key = ""
        if (
            "notificationPassword" in dict_
            and dict_["notificationPassword"] is not None
        ):
            instance.notification_password = str(dict_["notificationPassword"])
        elif include_empty:
            instance.notification_password = ""
        if (
            "notificationUsername" in dict_
            and dict_["notificationUsername"] is not None
        ):
            instance.notification_username = str(dict_["notificationUsername"])
        elif include_empty:
            instance.notification_username = ""
        if "returnUrl" in dict_ and dict_["returnUrl"] is not None:
            instance.return_url = str(dict_["returnUrl"])
        elif include_empty:
            instance.return_url = ""
        if "settings" in dict_ and dict_["settings"] is not None:
            instance.settings = str(dict_["settings"])
        elif include_empty:
            instance.settings = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, AdyenConfig]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[AdyenConfig]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[AdyenConfig, List[AdyenConfig], Dict[Any, AdyenConfig]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "allowedPaymentMethods": "allowed_payment_methods",
            "apiKey": "api_key",
            "authoriseAsCapture": "authorise_as_capture",
            "blockedPaymentMethods": "blocked_payment_methods",
            "clientKey": "client_key",
            "dropInSettings": "drop_in_settings",
            "liveEndpointUrlPrefix": "live_endpoint_url_prefix",
            "merchantAccount": "merchant_account",
            "notificationHmacKey": "notification_hmac_key",
            "notificationPassword": "notification_password",
            "notificationUsername": "notification_username",
            "returnUrl": "return_url",
            "settings": "settings",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "allowedPaymentMethods": False,
            "apiKey": False,
            "authoriseAsCapture": False,
            "blockedPaymentMethods": False,
            "clientKey": False,
            "dropInSettings": False,
            "liveEndpointUrlPrefix": False,
            "merchantAccount": False,
            "notificationHmacKey": False,
            "notificationPassword": False,
            "notificationUsername": False,
            "returnUrl": False,
            "settings": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.44.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model
from accelbyte_py_sdk.core import StrEnum


class EntitlementOriginEnum(StrEnum):
    EPIC = "Epic"
    GOOGLEPLAY = "GooglePlay"
    IOS = "IOS"
    NINTENDO = "Nintendo"
    OCULUS = "Oculus"
    OTHER = "Other"
    PLAYSTATION = "Playstation"
    STEAM = "Steam"
    SYSTEM = "System"
    TWITCH = "Twitch"
    XBOX = "Xbox"


class ItemIdentityTypeEnum(StrEnum):
    ITEM_ID = "ITEM_ID"
    ITEM_SKU = "ITEM_SKU"


class OriginEnum(StrEnum):
    EPIC = "Epic"
    GOOGLEPLAY = "GooglePlay"
    IOS = "IOS"
    NINTENDO = "Nintendo"
    OCULUS = "Oculus"
    OTHER = "Other"
    PLAYSTATION = "Playstation"
    STEAM = "Steam"
    SYSTEM = "System"
    TWITCH = "Twitch"
    XBOX = "Xbox"


class RevokeItem(Model):
    """Revoke item (RevokeItem)

    Properties:
        entitlement_origin: (entitlementOrigin) OPTIONAL Union[str, EntitlementOriginEnum]

        item_identity: (itemIdentity) OPTIONAL str

        item_identity_type: (itemIdentityType) OPTIONAL Union[str, ItemIdentityTypeEnum]

        origin: (origin) OPTIONAL Union[str, OriginEnum]
    """

    # region fields

    entitlement_origin: Union[str, EntitlementOriginEnum]  # OPTIONAL
    item_identity: str  # OPTIONAL
    item_identity_type: Union[str, ItemIdentityTypeEnum]  # OPTIONAL
    origin: Union[str, OriginEnum]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_entitlement_origin(
        self, value: Union[str, EntitlementOriginEnum]
    ) -> RevokeItem:
        self.entitlement_origin = value
        return self

    def with_item_identity(self, value: str) -> RevokeItem:
        self.item_identity = value
        return self

    def with_item_identity_type(
        self, value: Union[str, ItemIdentityTypeEnum]
    ) -> RevokeItem:
        self.item_identity_type = value
        return self

    def with_origin(self, value: Union[str, OriginEnum]) -> RevokeItem:
        self.origin = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "entitlement_origin"):
            result["entitlementOrigin"] = str(self.entitlement_origin)
        elif include_empty:
            result["entitlementOrigin"] = Union[str, EntitlementOriginEnum]()
        if hasattr(self, "item_identity"):
            result["itemIdentity"] = str(self.item_identity)
        elif include_empty:
            result["itemIdentity"] = ""
        if hasattr(self, "item_identity_type"):
            result["itemIdentityType"] = str(self.item_identity_type)
        elif include_empty:
            result["itemIdentityType"] = Union[str, ItemIdentityTypeEnum]()
        if hasattr(self, "origin"):
            result["origin"] = str(self.origin)
        elif include_empty:
            result["origin"] = Union[str, OriginEnum]()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        entitlement_origin: Optional[Union[str, EntitlementOriginEnum]] = None,
        item_identity: Optional[str] = None,
        item_identity_type: Optional[Union[str, ItemIdentityTypeEnum]] = None,
        origin: Optional[Union[str, OriginEnum]] = None,
        **kwargs,
    ) -> RevokeItem:
        instance = cls()
        if entitlement_origin is not None:
            instance.entitlement_origin = entitlement_origin
        if item_identity is not None:
            instance.item_identity = item_identity
        if item_identity_type is not None:
            instance.item_identity_type = item_identity_type
        if origin is not None:
            instance.origin = origin
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> RevokeItem:
        instance = cls()
        if not dict_:
            return instance
        if "entitlementOrigin" in dict_ and dict_["entitlementOrigin"] is not None:
            instance.entitlement_origin = str(dict_["entitlementOrigin"])
        elif include_empty:
            instance.entitlement_origin = Union[str, EntitlementOriginEnum]()
        if "itemIdentity" in dict_ and dict_["itemIdentity"] is not None:
            instance.item_identity = str(dict_["itemIdentity"])
        elif include_empty:
            instance.item_identity = ""
        if "itemIdentityType" in dict_ and dict_["itemIdentityType"] is not None:
            instance.item_identity_type = str(dict_["itemIdentityType"])
        elif include_empty:
            instance.item_identity_type = Union[str, ItemIdentityTypeEnum]()
        if "origin" in dict_ and dict_["origin"] is not None:
            instance.origin = str(dict_["origin"])
        elif include_empty:
            instance.origin = Union[str, OriginEnum]()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, RevokeItem]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[RevokeItem]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[RevokeItem, List[RevokeItem], Dict[Any, RevokeItem]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "entitlementOrigin": "entitlement_origin",
            "itemIdentity": "item_identity",
            "itemIdentityType": "item_identity_type",
            "origin": "origin",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "entitlementOrigin": False,
            "itemIdentity": False,
            "itemIdentityType": False,
            "origin": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "entitlementOrigin": [
                "Epic",
                "GooglePlay",
                "IOS",
                "Nintendo",
                "Oculus",
                "Other",
                "Playstation",
                "Steam",
                "System",
                "Twitch",
                "Xbox",
            ],
            "itemIdentityType": ["ITEM_ID", "ITEM_SKU"],
            "origin": [
                "Epic",
                "GooglePlay",
                "IOS",
                "Nintendo",
                "Oculus",
                "Other",
                "Playstation",
                "Steam",
                "System",
                "Twitch",
                "Xbox",
            ],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "4.44.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .get_payment_customization import GetPaymentCustomization
from .get_payment_customization import (
    PaymentProviderEnum as GetPaymentCustomizationPaymentProviderEnum,
)
from .get_payment_public_config import GetPaymentPublicConfig
from .get_payment_public_config import (
    PaymentProviderEnum as GetPaymentPublicConfigPaymentProviderEnum,
)
from .get_payment_tax_value import GetPaymentTaxValue
from .get_payment_tax_value import (
    PaymentProviderEnum as GetPaymentTaxValuePaymentProviderEnum,
)
from .pay import Pay
from .pay import (
    PaymentProviderEnum as PayPaymentProviderEnum,
)
from .public_check_payment_or_dec069 import PublicCheckPaymentOrderPaidStatus
from .public_get_payment_methods import PublicGetPaymentMethods
from .public_get_payment_url import PublicGetPaymentUrl
from .public_get_qr_code import PublicGetQRCode
from .public_get_unpaid_payme_26d8dd import PublicGetUnpaidPaymentOrder
from .public_normalize_paymen_6657a5 import PublicNormalizePaymentReturnUrl
from .public_normalize_paymen_6657a5 import (
    PaymentProviderEnum as PublicNormalizePaymentReturnUrlPaymentProviderEnum,
)



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Platform Service (4.44.0)

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Operation
from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import HttpResponse
from accelbyte_py_sdk.core import StrEnum

from ...models import ErrorEntity
from ...models import PaymentProcessResult
from ...models import PaymentToken


class PaymentProviderEnum(StrEnum):
    ADYEN = "ADYEN"
    ALIPAY = "ALIPAY"
    CHECKOUT = "CHECKOUT"
    PAYPAL = "PAYPAL"
    STRIPE = "STRIPE"
    WALLET = "WALLET"
    WXPAY = "WXPAY"
    XSOLLA = "XSOLLA"


class Pay(Operation):
    """Do payment (pay)

    [Not Supported Yet In Starter] Do payment(For now, this only support checkout.com).
    Other detail info:

      * Returns : Payment process result

    Properties:
        url: /platform/public/namespaces/{namespace}/payment/orders/{paymentOrderNo}/pay

        method: POST

        tags: ["PaymentStation"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]


        body: (body) OPTIONAL PaymentToken in body

        namespace: (namespace) REQUIRED str in path

        payment_order_no: (paymentOrderNo) REQUIRED str in path

        payment_provider: (paymentProvider) OPTIONAL Union[str, PaymentProviderEnum] in query

        zip_code: (zipCode) OPTIONAL str in query

    Responses:
        200: OK - PaymentProcessResult (successful operation)

        400: Bad Request - ErrorEntity (33322: Payment provider [{paymentProvider}] not supported)

        404: Not Found - ErrorEntity (33141: Payment Order [{paymentOrderNo}] does not exist)

        409: Conflict - ErrorEntity (33171: Invalid payment order status [{status}] for payment order [{paymentOrderNo}])
    """

    # region fields

    _url: str = (
        "/platform/public/namespaces/{namespace}/payment/orders/{paymentOrderNo}/pay"
    )
    _method: str = "POST"
    _consumes: List[str] = ["application/json"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    body: PaymentToken  # OPTIONAL in [body]
    namespace: str  # REQUIRED in [path]
    payment_order_no: str  # REQUIRED in [path]
    payment_provider: Union[str, PaymentProviderEnum]  # OPTIONAL in [query]
    zip_code: str  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "body": self.get_body_params(),
            "path": self.get_path_params(),
            "query": self.get_query_params(),
        }

    def get_body_params(self) -> Any:
        if not hasattr(self, "body") or self.body is None:
            return None
        return self.body.to_dict()

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        if hasattr(self, "payment_order_no"):
            result["paymentOrderNo"] = self.payment_order_no
        return result

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "payment_provider"):
            result["paymentProvider"] = self.payment_provider
        if hasattr(self, "zip_code"):
            result["zipCode"] = self.zip_code
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_body(self, value: PaymentToken) -> Pay:
        self.body = value
        return self

    def with_namespace(self, value: str) -> Pay:
        self.namespace = value
        return self

    def with_payment_order_no(self, value: str) -> Pay:
        self.payment_order_no = value
        return self

    def with_payment_provider(self, value: Union[str, PaymentProviderEnum]) -> Pay:
        self.payment_provider = value
        return self

    def with_zip_code(self, value: str) -> Pay:
        self.zip_code = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "body") and self.body:
            result["body"] = self.body.to_dict(include_empty=include_empty)
        elif include_empty:
            result["body"] = PaymentToken()
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "payment_order_no") and self.payment_order_no:
            result["paymentOrderNo"] = str(self.payment_order_no)
        elif include_empty:
            result["paymentOrderNo"] = ""
        if hasattr(self, "payment_provider") and self.payment_provider:
            result["paymentProvider"] = str(self.payment_provider)
        elif include_empty:
            result["paymentProvider"] = Union[str, PaymentProviderEnum]()
        if hasattr(self, "zip_code") and self.zip_code:
            result["zipCode"] = str(self.zip_code)
        elif include_empty:
            result["zipCode"] = ""
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, PaymentProcessResult], Union[None, ErrorEntity, HttpResponse]
    ]:
        """Parse the given response.

        200: OK - PaymentProcessResult (successful operation)

        400: Bad Request - ErrorEntity (33322: Payment provider [{paymentProvider}] not supported)

        404: Not Found - ErrorEntity (33141: Payment Order [{paymentOrderNo}] does not exist)

        409: Conflict - ErrorEntity (33171: Invalid payment order status [{status}] for payment order [{paymentOrderNo}])

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return PaymentProcessResult.create_from_dict(content), None
        if code == 400:
            return None, ErrorEntity.create_from_dict(content)
        if code == 404:
            return None, ErrorEntity.create_from_dict(content)
        if code == 409:
            return None, ErrorEntity.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        namespace: str,
        payment_order_no: str,
        body: Optional[PaymentToken] = None,
        payment_provider: Optional[Union[str, PaymentProviderEnum]] = None,
        zip_code: Optional[str] = None,
        **kwargs,
    ) -> Pay:
        instance = cls()
        instance.namespace = namespace
        instance.payment_order_no = payment_order_no
        if body is not None:
            instance.body = body
        if payment_provider is not None:
            instance.payment_provider = payment_provider
        if zip_code is not None:
            instance.zip_code = zip_code
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> Pay:
        instance = cls()
        if "body" in dict_ and dict_["body"] is not None:
            instance.body = PaymentToken.create_from_dict(
                dict_["body"], include_empty=include_empty
            )
        elif include_empty:
            instance.body = PaymentToken()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "paymentOrderNo" in dict_ and dict_["paymentOrderNo"] is not None:
            instance.payment_order_no = str(dict_["paymentOrderNo"])
        elif include_empty:
            instance.payment_order_no = ""
        if "paymentProvider" in dict_ and dict_["paymentProvider"] is not None:
            instance.payment_provider = str(dict_["paymentProvider"])
        elif include_empty:
            instance.payment_provider = Union[str, PaymentProviderEnum]()
        if "zipCode" in dict_ and dict_["zipCode"] is not None:
            instance.zip_code = str(dict_["zipCode"])
        elif include_empty:
            instance.zip_code = ""
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "body": "body",
            "namespace": "namespace",
            "paymentOrderNo": "payment_order_no",
            "paymentProvider": "payment_provider",
            "zipCode": "zip_code",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "body": False,
            "namespace": True,
            "paymentOrderNo": True,
            "paymentProvider": False,
            "zipCode": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "paymentProvider": [
                "ADYEN",
                "ALIPAY",
                "CHECKOUT",
                "PAYPAL",
                "STRIPE",
                "WALLET",
                "WXPAY",
                "XSOLLA",
            ],  # in query
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Platform Service (4.44.0)

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Operation
from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import HttpResponse

from ...models import ErrorEntity
from ...models import ImportStoreResult


class ImportStore1(Operation):
    """Import a store (importStore_1)

    This API is used to import a store.

    Other detail info:

      * Required permission : resource="ADMIN:NAMESPACE:{namespace}:STORE", action=4 (UPDATE)

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:STORE [UPDATE]

    Properties:
        url: /platform/v2/admin/namespaces/{namespace}/stores/import

        method: PUT

        tags: ["Store"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        file: (file) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

        store_id: (storeId) OPTIONAL str in query

        strict_mode: (strictMode) OPTIONAL bool in query

    Responses:
        200: OK - ImportStoreResult (successful operation)

        400: Bad Request - ErrorEntity (30121: Store data is invalid | 30122: Store's meta mismatch)

        404: Not Found - ErrorEntity (30141: Store [{storeId}] does not exist in namespace [{namespace}])
    """

    # region fields

    _url: str = "/platform/v2/admin/namespaces/{namespace}/stores/import"
    _method: str = "PUT"
    _consumes: List[str] = ["multipart/form-data"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"], ["BEARER_AUTH"]]
    _location_query: str = None

    file: Any  # OPTIONAL in [form_data]
    namespace: str  # REQUIRED in [path]
    store_id: str  # OPTIONAL in [query]
    strict_mode: bool  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "form_data": self.get_form_data_params(),
            "path": self.get_path_params(),
            "query": self.get_query_params(),
        }

    def get_form_data_params(self) -> dict:
        result = {}
        if hasattr(self, "file"):
            result["file"] = self.file
        return result

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        return result

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "store_id"):
            result["storeId"] = self.store_id
        if hasattr(self, "strict_mode"):
            result["strictMode"] = self.strict_mode
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_file(self, value: Any) -> ImportStore1:
        self.file = value
        return self

    def with_namespace(self, value: str) -> ImportStore1:
        self.namespace = value
        return self

    def with_store_id(self, value: str) -> ImportStore1:
        self.store_id = value
        return self

    def with_strict_mode(self, value: bool) -> ImportStore1:
        self.strict_mode = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "file") and self.file:
            result["file"] = Any(self.file)
        elif include_empty:
            result["file"] = Any()
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "store_id") and self.store_id:
            result["storeId"] = str(self.store_id)
        elif include_empty:
            result["storeId"] = ""
        if hasattr(self, "strict_mode") and self.strict_mode:
            result["strictMode"] = bool(self.strict_mode)
        elif include_empty:
            result["strictMode"] = False
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[Union[None, ImportStoreResult], Union[None, ErrorEntity, HttpResponse]]:
        """Parse the given response.

        200: OK - ImportStoreResult (successful operation)

        400: Bad Request - ErrorEntity (30121: Store data is invalid | 30122: Store's meta mismatch)

        404: Not Found - ErrorEntity (30141: Store [{storeId}] does not exist in namespace [{namespace}])

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return ImportStoreResult.create_from_dict(content), None
        if code == 400:
            return None, ErrorEntity.create_from_dict(content)
        if code == 404:
            return None, ErrorEntity.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        namespace: str,
        file: Optional[Any] = None,
        store_id: Optional[str] = None,
        strict_mode: Optional[bool] = None,
        **kwargs,
    ) -> ImportStore1:
        instance = cls()
        instance.namespace = namespace
        if file is not None:
            instance.file = file
        if store_id is not None:
            instance.store_id = store_id
        if strict_mode is not None:
            instance.strict_mode = strict_mode
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> ImportStore1:
        instance = cls()
        if "file" in dict_ and dict_["file"] is not None:
            instance.file = Any(dict_["file"])
        elif include_empty:
            instance.file = Any()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "storeId" in dict_ and dict_["storeId"] is not None:
            instance.store_id = str(dict_["storeId"])
        elif include_empty:
            instance.store_id = ""
        if "strictMode" in dict_ and dict_["strictMode"] is not None:
            instance.strict_mode = bool(dict_["strictMode"])
        elif include_empty:
            instance.strict_mode = False
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "file": "file",
            "namespace": "namespace",
            "storeId": "store_id",
            "strictMode": "strict_mode",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "file": False,
            "namespace": True,
            "storeId": False,
            "strictMode": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.44.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.invoice_currency_summary import InvoiceCurrencySummary


class InvoiceSummary(Model):
    """Invoice summary (InvoiceSummary)

    Properties:
        invoice_currency_summary: (invoiceCurrencySummary) REQUIRED List[InvoiceCurrencySummary]

        total_sales_volume: (totalSalesVolume) REQUIRED int
    """

    # region fields

    invoice_currency_summary: List[InvoiceCurrencySummary]  # REQUIRED
    total_sales_volume: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_invoice_currency_summary(
        self, value: List[InvoiceCurrencySummary]
    ) -> InvoiceSummary:
        self.invoice_currency_summary = value
        return self

    def with_total_sales_volume(self, value: int) -> InvoiceSummary:
        self.total_sales_volume = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "invoice_currency_summary"):
            result["invoiceCurrencySummary"] = [
                i0.to_dict(include_empty=include_empty)
                for i0 in self.invoice_currency_summary
            ]
        elif include_empty:
            result["invoiceCurrencySummary"] = []
        if hasattr(self, "total_sales_volume"):
            result["totalSalesVolume"] = int(self.total_sales_volume)
        elif include_empty:
            result["totalSalesVolume"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        invoice_currency_summary: List[InvoiceCurrencySummary],
        total_sales_volume: int,
        **kwargs,
    ) -> InvoiceSummary:
        instance = cls()
        instance.invoice_currency_summary = invoice_currency_summary
        instance.total_sales_volume = total_sales_volume
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> InvoiceSummary:
        instance = cls()
        if not dict_:
            return instance
        if (
            "invoiceCurrencySummary" in dict_
            and dict_["invoiceCurrencySummary"] is not None
        ):
            instance.invoice_currency_summary = [
                InvoiceCurrencySummary.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["invoiceCurrencySummary"]
            ]
        elif include_empty:
            instance.invoice_currency_summary = []
        if "totalSalesVolume" in dict_ and dict_["totalSalesVolume"] is not None:
            instance.total_sales_volume = int(dict_["totalSalesVolume"])
        elif include_empty:
            instance.total_sales_volume = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, InvoiceSummary]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[InvoiceSummary]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[InvoiceSummary, List[InvoiceSummary], Dict[Any, InvoiceSummary]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "invoiceCurrencySummary": "invoice_currency_summary",
            "totalSalesVolume": "total_sales_volume",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "invoiceCurrencySummary": True,
            "totalSalesVolume": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.44.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class Localization(Model):
    """Localization (Localization)

    Properties:
        title: (title) REQUIRED str

        description: (description) OPTIONAL str

        local_ext: (localExt) OPTIONAL Dict[str, Any]

        long_description: (longDescription) OPTIONAL str
    """

    # region fields

    title: str  # REQUIRED
    description: str  # OPTIONAL
    local_ext: Dict[str, Any]  # OPTIONAL
    long_description: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_title(self, value: str) -> Localization:
        self.title = value
        return self

    def with_description(self, value: str) -> Localization:
        self.description = value
        return self

    def with_local_ext(self, value: Dict[str, Any]) -> Localization:
        self.local_ext = value
        return self

    def with_long_description(self, value: str) -> Localization:
        self.long_description = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "title"):
            result["title"] = str(self.title)
        elif include_empty:
            result["title"] = ""
        if hasattr(self, "description"):
            result["description"] = str(self.description)
        elif include_empty:
            result["description"] = ""
        if hasattr(self, "local_ext"):
            result["localExt"] = {str(k0): v0 for k0, v0 in self.local_ext.items()}
        elif include_empty:
            result["localExt"] = {}
        if hasattr(self, "long_description"):
            result["longDescription"] = str(self.long_description)
        elif include_empty:
            result["longDescription"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        title: str,
        description: Optional[str] = None,
        local_ext: Optional[Dict[str, Any]] = None,
        long_description: Optional[str] = None,
        **kwargs,
    ) -> Localization:
        instance = cls()
        instance.title = title
        if description is not None:
            instance.description = description
        if local_ext is not None:
            instance.local_ext = local_ext
        if long_description is not None:
            instance.long_description = long_description
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> Localization:
        instance = cls()
        if not dict_:
            return instance
        if "title" in dict_ and dict_["title"] is not None:
            instance.title = str(dict_["title"])
        elif include_empty:
            instance.title = ""
        if "description" in dict_ and dict_["description"] is not None:
            instance.description = str(dict_["description"])
        elif include_empty:
            instance.description = ""
        if "localExt" in dict_ and dict_["localExt"] is not None:
            instance.local_ext = {str(k0): v0 for k0, v0 in dict_["localExt"].items()}
        elif include_empty:
            instance.local_ext = {}
        if "longDescription" in dict_ and dict_["longDescription"] is not None:
            instance.long_description = str(dict_["longDescription"])
        elif include_empty:
            instance.long_description = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, Localization]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[Localization]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[Localization, List[Localization], Dict[Any, Localization]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "title": "title",
            "description": "description",
            "localExt": "local_ext",
            "longDescription": "long_description",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "title": True,
            "description": False,
            "localExt": False,
            "longDescription": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Platform Service (4.44.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.adyen_config import AdyenConfig
from ..models.ali_pay_config import AliPayConfig
from ..models.checkout_config import CheckoutConfig
from ..models.pay_pal_config import PayPalConfig
from ..models.stripe_config import StripeConfig
from ..models.wx_pay_config_info import WxPayConfigInfo
from ..models.xsolla_config import XsollaConfig
from ..models.xsolla_paywall_config import XsollaPaywallConfig


class PaymentMerchantConfigInfo(Model):
    """Payment merchant config info (PaymentMerchantConfigInfo)

    Properties:
        created_at: (createdAt) REQUIRED str

        id_: (id) REQUIRED str

        updated_at: (updatedAt) REQUIRED str

        adyen_config: (adyenConfig) OPTIONAL AdyenConfig

        adyen_sandbox_config: (adyenSandboxConfig) OPTIONAL AdyenConfig

        ali_pay_config: (aliPayConfig) OPTIONAL AliPayConfig

        ali_pay_sandbox_config: (aliPaySandboxConfig) OPTIONAL AliPayConfig

        checkout_config: (checkoutConfig) OPTIONAL CheckoutConfig

        checkout_sandbox_config: (checkoutSandboxConfig) OPTIONAL CheckoutConfig

        pay_pal_config: (payPalConfig) OPTIONAL PayPalConfig

        pay_pal_sandbox_config: (payPalSandboxConfig) OPTIONAL PayPalConfig

        stripe_config: (stripeConfig) OPTIONAL StripeConfig

        stripe_sandbox_config: (stripeSandboxConfig) OPTIONAL StripeConfig

        wx_pay_config: (wxPayConfig) OPTIONAL WxPayConfigInfo

        xsolla_config: (xsollaConfig) OPTIONAL XsollaConfig

        xsolla_paywall_config: (xsollaPaywallConfig) OPTIONAL XsollaPaywallConfig
    """

    # region fields

    created_at: str  # REQUIRED
    id_: str  # REQUIRED
    updated_at: str  # REQUIRED
    adyen_config: AdyenConfig  # OPTIONAL
    adyen_sandbox_config: AdyenConfig  # OPTIONAL
    ali_pay_config: AliPayConfig  # OPTIONAL
    ali_pay_sandbox_config: AliPayConfig  # OPTIONAL
    checkout_config: CheckoutConfig  # OPTIONAL
    checkout_sandbox_config: CheckoutConfig  # OPTIONAL
    pay_pal_config: PayPalConfig  # OPTIONAL
    pay_pal_sandbox_config: PayPalConfig  # OPTIONAL
    stripe_config: StripeConfig  # OPTIONAL
    stripe_sandbox_config: StripeConfig  # OPTIONAL
    wx_pay_config: WxPayConfigInfo  # OPTIONAL
    xsolla_config: XsollaConfig  # OPTIONAL
    xsolla_paywall_config: XsollaPaywallConfig  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: str) -> PaymentMerchantConfigInfo:
        self.created_at = value
        return self

    def with_id(self, value: str) -> PaymentMerchantConfigInfo:
        self.id_ = value
        return self

    def with_updated_at(self, value: str) -> PaymentMerchantConfigInfo:
        self.updated_at = value
        return self

    def with_adyen_config(self, value: AdyenConfig) -> PaymentMerchantConfigInfo:
        self.adyen_config = value
        return self

    def with_adyen_sandbox_config(
        self, value: AdyenConfig
    ) -> PaymentMerchantConfigInfo:
        self.adyen_sandbox_config = value
        return self

    def with_ali_pay_config(self, value: AliPayConfig) -> PaymentMerchantConfigInfo:
        self.ali_pay_config = value
        return self

    def with_ali_pay_sandbox_config(
        self, value: AliPayConfig
    ) -> PaymentMerchantConfigInfo:
        self.ali_pay_sandbox_config = value
        return self

    def with_checkout_config(self, value: CheckoutConfig) -> PaymentMerchantConfigInfo:
        self.checkout_config = value
        return self

    def with_checkout_sandbox_config(
        self, value: CheckoutConfig
    ) -> PaymentMerchantConfigInfo:
        self.checkout_sandbox_config = value
        return self

    def with_pay_pal_config(self, value: PayPalConfig) -> PaymentMerchantConfigInfo:
        self.pay_pal_config = value
        return self

    def with_pay_pal_sandbox_config(
        self, value: PayPalConfig
    ) -> PaymentMerchantConfigInfo:
        self.pay_pal_sandbox_config = value
        return self

    def with_stripe_config(self, value: StripeConfig) -> PaymentMerchantConfigInfo:
        self.stripe_config = value
        return self

    def with_stripe_sandbox_config(
        self, value: StripeConfig
    ) -> PaymentMerchantConfigInfo:
        self.stripe_sandbox_config = value
        return self

    def with_wx_pay_config(self, value: WxPayConfigInfo) -> PaymentMerchantConfigInfo:
        self.wx_pay_config = value
        return self

    def with_xsolla_config(self, value: XsollaConfig) -> PaymentMerchantConfigInfo:
        self.xsolla_config = value
        return self

    def with_xsolla_paywall_config(
        self, value: XsollaPaywallConfig
    ) -> PaymentMerchantConfigInfo:
        self.xsolla_paywall_config = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "updated_at"):
            result["updatedAt"] = str(self.updated_at)
        elif include_empty:
            result["updatedAt"] = ""
        if hasattr(self, "adyen_config"):
            result["adyenConfig"] = self.adyen_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["adyenConfig"] = AdyenConfig()
        if hasattr(self, "adyen_sandbox_config"):
            result["adyenSandboxConfig"] = self.adyen_sandbox_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["adyenSandboxConfig"] = AdyenConfig()
        if hasattr(self, "ali_pay_config"):
            result["aliPayConfig"] = self.ali_pay_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["aliPayConfig"] = AliPayConfig()
        if hasattr(self, "ali_pay_sandbox_config"):
            result["aliPaySandboxConfig"] = self.ali_pay_sandbox_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["aliPaySandboxConfig"] = AliPayConfig()
        if hasattr(self, "checkout_config"):
            result["checkoutConfig"] = self.checkout_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["checkoutConfig"] = CheckoutConfig()
        if hasattr(self, "checkout_sandbox_config"):
            result["checkoutSandboxConfig"] = self.checkout_sandbox_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["checkoutSandboxConfig"] = CheckoutConfig()
        if hasattr(self, "pay_pal_config"):
            result["payPalConfig"] = self.pay_pal_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["payPalConfig"] = PayPalConfig()
        if hasattr(self, "pay_pal_sandbox_config"):
            result["payPalSandboxConfig"] = self.pay_pal_sandbox_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["payPalSandboxConfig"] = PayPalConfig()
        if hasattr(self, "stripe_config"):
            result["stripeConfig"] = self.stripe_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["stripeConfig"] = StripeConfig()
        if hasattr(self, "stripe_sandbox_config"):
            result["stripeSandboxConfig"] = self.stripe_sandbox_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["stripeSandboxConfig"] = StripeConfig()
        if hasattr(self, "wx_pay_config"):
            result["wxPayConfig"] = self.wx_pay_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["wxPayConfig"] = WxPayConfigInfo()
        if hasattr(self, "xsolla_config"):
            result["xsollaConfig"] = self.xsolla_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["xsollaConfig"] = XsollaConfig()
        if hasattr(self, "xsolla_paywall_config"):
            result["xsollaPaywallConfig"] = self.xsolla_paywall_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["xsollaPaywallConfig"] = XsollaPaywallConfig()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: str,
        id_: str,
        updated_at: str,
        adyen_config: Optional[AdyenConfig] = None,
        adyen_sandbox_config: Optional[AdyenConfig] = None,
        ali_pay_config: Optional[AliPayConfig] = None,
        ali_pay_sandbox_config: Optional[AliPayConfig] = None,
        checkout_config: Optional[CheckoutConfig] = None,
        checkout_sandbox_config: Optional[CheckoutConfig] = None,
        pay_pal_config: Optional[PayPalConfig] = None,
        pay_pal_sandbox_config: Optional[PayPalConfig] = None,
        stripe_config: Optional[StripeConfig] = None,
        stripe_sandbox_config: Optional[StripeConfig] = None,
        wx_pay_config: Optional[WxPayConfigInfo] = None,
        xsolla_config: Optional[XsollaConfig] = None,
        xsolla_paywall_config: Optional[XsollaPaywallConfig] = None,
        **kwargs,
    ) -> PaymentMerchantConfigInfo:
        instance = cls()
        instance.created_at = created_at
        instance.id_ = id_
        instance.updated_at = updated_at
        if adyen_config is not None:
            instance.adyen_config = adyen_config
        if adyen_sandbox_config is not None:
            instance.adyen_sandbox_config = adyen_sandbox_config
        if ali_pay_config is not None:
            instance.ali_pay_config = ali_pay_config
        if ali_pay_sandbox_config is not None:
            instance.ali_pay_sandbox_config = ali_pay_sandbox_config
        if checkout_config is not None:
            instance.checkout_config = checkout_config
        if checkout_sandbox_config is not None:
            instance.checkout_sandbox_config = checkout_sandbox_config
        if pay_pal_config is not None:
            instance.pay_pal_config = pay_pal_config
        if pay_pal_sandbox_config is not None:
            instance.pay_pal_sandbox_config = pay_pal_sandbox_config
        if stripe_config is not None:
            instance.stripe_config = stripe_config
        if stripe_sandbox_config is not None:
            instance.stripe_sandbox_config = stripe_sandbox_config
        if wx_pay_config is not None:
            instance.wx_pay_config = wx_pay_config
        if xsolla_config is not None:
            instance.xsolla_config = xsolla_config
        if xsolla_paywall_config is not None:
            instance.xsolla_paywall_config = xsolla_paywall_config
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> PaymentMerchantConfigInfo:
        instance = cls()
        if not dict_:
            return instance
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = str(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = ""
        if "adyenConfig" in dict_ and dict_["adyenConfig"] is not None:
            instance.adyen_config = AdyenConfig.create_from_dict(
                dict_["adyenConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.adyen_config = AdyenConfig()
        if "adyenSandboxConfig" in dict_ and dict_["adyenSandboxConfig"] is not None:
            instance.adyen_sandbox_config = AdyenConfig.create_from_dict(
                dict_["adyenSandboxConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.adyen_sandbox_config = AdyenConfig()
        if "aliPayConfig" in dict_ and dict_["aliPayConfig"] is not None:
            instance.ali_pay_config = AliPayConfig.create_from_dict(
                dict_["aliPayConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.ali_pay_config = AliPayConfig()
        if "aliPaySandboxConfig" in dict_ and dict_["aliPaySandboxConfig"] is not None:
            instance.ali_pay_sandbox_config = AliPayConfig.create_from_dict(
                dict_["aliPaySandboxConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.ali_pay_sandbox_config = AliPayConfig()
        if "checkoutConfig" in dict_ and dict_["checkoutConfig"] is not None:
            instance.checkout_config = CheckoutConfig.create_from_dict(
                dict_["checkoutConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.checkout_config = CheckoutConfig()
        if (
            "checkoutSandboxConfig" in dict_
            and dict_["checkoutSandboxConfig"] is not None
        ):
            instance.checkout_sandbox_config = CheckoutConfig.create_from_dict(
                dict_["checkoutSandboxConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.checkout_sandbox_config = CheckoutConfig()
        if "payPalConfig" in dict_ and dict_["payPalConfig"] is not None:
            instance.pay_pal_config = PayPalConfig.create_from_dict(
                dict_["payPalConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.pay_pal_config = PayPalConfig()
        if "payPalSandboxConfig" in dict_ and dict_["payPalSandboxConfig"] is not None:
            instance.pay_pal_sandbox_config = PayPalConfig.create_from_dict(
                dict_["payPalSandboxConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.pay_pal_sandbox_config = PayPalConfig()
        if "stripeConfig" in dict_ and dict_["stripeConfig"] is not None:
            instance.stripe_config = StripeConfig.create_from_dict(
                dict_["stripeConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.stripe_config = StripeConfig()
        if "stripeSandboxConfig" in dict_ and dict_["stripeSandboxConfig"] is not None:
            instance.stripe_sandbox_config = StripeConfig.create_from_dict(
                dict_["stripeSandboxConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.stripe_sandbox_config = StripeConfig()
        if "wxPayConfig" in dict_ and dict_["wxPayConfig"] is not None:
            instance.wx_pay_config = WxPayConfigInfo.create_from_dict(
                dict_["wxPayConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.wx_pay_config = WxPayConfigInfo()
        if "xsollaConfig" in dict_ and dict_["xsollaConfig"] is not None:
            instance.xsolla_config = XsollaConfig.create_from_dict(
                dict_["xsollaConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.xsolla_config = XsollaConfig()
        if "xsollaPaywallConfig" in dict_ and dict_["xsollaPaywallConfig"] is not None:
            instance.xsolla_paywall_config = XsollaPaywallConfig.create_from_dict(
                dict_["xsollaPaywallConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.xsolla_paywall_config = XsollaPaywallConfig()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, PaymentMerchantConfigInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[PaymentMerchantConfigInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        PaymentMerchantConfigInfo,
        List[PaymentMerchantConfigInfo],
        Dict[Any, PaymentMerchantConfigInfo],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "createdAt": "created_at",
            "id": "id_",
            "updatedAt": "updated_at",
            "adyenConfig": "adyen_config",
            "adyenSandboxConfig": "adyen_sandbox_config",
            "aliPayConfig": "ali_pay_config",
            "aliPaySandboxConfig": "ali_pay_sandbox_config",
            "checkoutConfig": "checkout_config",
            "checkoutSandboxConfig": "checkout_sandbox_config",
            "payPalConfig": "pay_pal_config",
            "payPalSandboxConfig": "pay_pal_sandbox_config",
            "stripeConfig": "stripe_config",
            "stripeSandboxConfig": "stripe_sandbox_config",
            "wxPayConfig": "wx_pay_config",
            "xsollaConfig": "xsolla_config",
            "xsollaPaywallConfig": "xsolla_paywall_config",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "createdAt": True,
            "id": True,
            "updatedAt": True,
            "adyenConfig": False,
            "adyenSandboxConfig": False,
            "aliPayConfig": False,
            "aliPaySandboxConfig": False,
            "checkoutConfig": False,
            "checkoutSandboxConfig": False,
            "payPalConfig": False,
            "payPalSandboxConfig": False,
            "stripeConfig": False,
            "stripeSandboxConfig": False,
            "wxPayConfig": False,
            "xsollaConfig": False,
            "xsollaPaywallConfig": False,
        }

    # endregion static methods
